==> connector-service-1.0.0-20190312.034908-12-sources.jar: com/bizvane/connectorservice/entity/common/OrderItemRequestVO.java <==
package com.bizvane.connectorservice.entity.common;

/**
 * @author liuying
 * @date 2018/8/14
 * @description
 */

public class OrderItemRequestVO {

    /**
     * 数量
     */
    private Integer count;

    /**
     * 市场价
     */
    private Double price;

    /**
     * 规格(商品样式)
     */
    private String specification;

    /**
     * 商品编号
     */
    private String code;

    /**
     * 标准价(吊牌价)
     */
    private Double standardPrice;

    /**
     * 标准金额 = 标准价 * 数量
     */
    private Double standardAmount;

    /**
     * 销售价 = 应收金额 * 数量
     */
    private Double marketValue;

    /**
     * 应收金额
     */
    private Double amountReceivable;

    /**
     * 成交价
     */
    private Double transactionAmount;

    public Integer getCount() {
        return count;
    }

    public void setCount(Integer count) {
        this.count = count;
    }

    public Double getPrice() {
        return price;
    }

    public void setPrice(Double price) {
        this.price = price;
    }

    public String getSpecification() {
        return specification;
    }

    public void setSpecification(String specification) {
        this.specification = specification;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public Double getStandardPrice() {
        return standardPrice;
    }

    public void setStandardPrice(Double standardPrice) {
        this.standardPrice = standardPrice;
    }

    public Double getStandardAmount() {
        return standardAmount;
    }

    public void setStandardAmount(Double standardAmount) {
        this.standardAmount = standardAmount;
    }

    public Double getMarketValue() {
        return marketValue;
    }

    public void setMarketValue(Double marketValue) {
        this.marketValue = marketValue;
    }

    public Double getAmountReceivable() {
        return amountReceivable;
    }

    public void setAmountReceivable(Double amountReceivable) {
        this.amountReceivable = amountReceivable;
    }

    public Double getTransactionAmount() {
        return transactionAmount;
    }

    public void setTransactionAmount(Double transactionAmount) {
        this.transactionAmount = transactionAmount;
    }
}

==> connector-service-1.0.0-20190703.125244-22-sources.jar: com/bizvane/connectorservice/entity/common/OrderItemRequestVO.java <==
package com.bizvane.connectorservice.entity.common;

import java.io.Serializable;

/**
 * @author liuying
 * @date 2018/8/14
 * @description
 */

public class OrderItemRequestVO implements Serializable {

    /**
     * 数量
     */
    private Integer count;

    /**
     * 市场价
     */
    private Double price;

    /**
     * 规格(商品样式)
     */
    private String specification;

    /**
     * 商品编号
     */
    private String code;

    /**
     * 标准价(吊牌价)
     */
    private Double standardPrice;

    /**
     * 标准金额 = 标准价 * 数量
     */
    private Double standardAmount;

    /**
     * 销售价 = 应收金额 * 数量
     */
    private Double marketValue;

    /**
     * 应收金额
     */
    private Double amountReceivable;

    /**
     * 成交价
     */
    private Double transactionAmount;

    public Integer getCount() {
        return count;
    }

    public void setCount(Integer count) {
        this.count = count;
    }

    public Double getPrice() {
        return price;
    }

    public void setPrice(Double price) {
        this.price = price;
    }

    public String getSpecification() {
        return specification;
    }

    public void setSpecification(String specification) {
        this.specification = specification;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public Double getStandardPrice() {
        return standardPrice;
    }

    public void setStandardPrice(Double standardPrice) {
        this.standardPrice = standardPrice;
    }

    public Double getStandardAmount() {
        return standardAmount;
    }

    public void setStandardAmount(Double standardAmount) {
        this.standardAmount = standardAmount;
    }

    public Double getMarketValue() {
        return marketValue;
    }

    public void setMarketValue(Double marketValue) {
        this.marketValue = marketValue;
    }

    public Double getAmountReceivable() {
        return amountReceivable;
    }

    public void setAmountReceivable(Double amountReceivable) {
        this.amountReceivable = amountReceivable;
    }

    public Double getTransactionAmount() {
        return transactionAmount;
    }

    public void setTransactionAmount(Double transactionAmount) {
        this.transactionAmount = transactionAmount;
    }
}
